==> scummvm_2.2.0+dfsg1.orig.tar.xz: scummvm-2.2.0/devtools/create_kyradat/resources/hof_dos_cd_italian.h <==
static const char *const k2SeqplayStringsDOSCDItalian[104] = {
	"Kyrandia sta svanendo!",
	"Roccia dopo roccia...",
	"...ed albero dopo albero.",
	"Kyrandia cessa di esistere!",
	"I mistici Reali sono sconcertati.",
	"Ogni libro ""\x8A"" stato consultato.",
	"Perfino Marko ed il suo nuovo aiutante sono stati invitati alla conferenza.",
	"Fortunatamente, la Mano era ferrata in materia.",
	"E finalmente un piano ""\x8A"" stato approvato.",
	"Bisogna recuperare un'Ancora di pietra",
	"dal centro della terra.",
	"Zanthia, la pi""\x97"" giovane trai Mistici, ""\x8A"" stata scelta per recuperare l'artefatto.",
	"Grazie per aver giocato a Hand of Fate.",
	"Questi mirtilli dovrebbero bastare ad aprire un portale per il centro della terra.",
	"X",
	"X",
	"Hey! Hanno rubato tutto il mio equipaggiamento!",
	"X",
	"Se pensano che vada fin laggi""\x97"" a piedi, si sbagliano di grosso!",
	"X",
	"X",
	"Sbrigati Fauno!",
	"Ragazzi, c'""\x8A"" mancato un pelo!",
	"Puoi dirlo forte. Io ho chiuso con la caccia!",
	"Ribbit.",
	"Quante volte devo dirtelo? Sei un rospo.",
	"Oh no! Abbiamo finito il formaggio!",
	"Proviamo con questo cerume. E' arancione.",
	"Mamy, mi dai l'edera?",
	"Via di qui, scio'!",
	"Tu taglio, e io scelgo.",
	"No. TU tagli e IO scelgo.",
	"Sono sempre convinto che fosse un'emerita cretinata.",
	"Non riconosceresti un pentametro in verso giambico nemmeno se ti mordesse le chiappe!",
	"Produttore Esecutivo",
	"Brett W. Sperry",
	"Direzione&Progetto",
	"Rick Gush",
	"Capo Programmatore",
	"Michael Legg",
	"Supervisione Artistica",
	"Louis Castle",
	"Joseph B. Hewitt IV",
	"Artista",
	"Rick Parks",
	"Codice aggiuntivo",
	"Philip W. Gorrow",
	"Mike Grayford",
	"Mark McCubbin",
	"Artisti",
	"Cameron Chun",
	"Cary Averett",
	"Cindy Chinn",
	"Elie Arabian",
	"Fei Cheng",
	"Ferby Miguel",
	"Frank Mendeola",
	"Jack Martin",
	"Jerry Moore",
	"X",
	"Judith Peterson",
	"Larry Miller",
	"Lenny Lee",
	"Louise Sandoval",
	"Ren Olsen",
	"Musica & Suoni",
	"Paul Mudra",
	"Frank Klepacki",
	"Dwight Okahara",
	"Pat Collins",
	"Controllo Qualit""\x85",
	"Glenn Sperry",
	"Michael Lightner",
	"William Foster",
	"Jesse Clemit",
	"Jeff Fillhaber",
	"Manuale, Confezione",
	"& Realizzazione",
	"Eydie Laramore",
	"Lisa Marcinko",
	"Lauren Rifkin",
	"Congratulazioni!",
	"Grazie per aver giocato a Hand of Fate!",
	"Codice extra",
	" contatti ",
	"Scott Duckett",
	"Irvine Testers",
	"Chris McFarland",
	"Paul Moore",
	"Chad Soares",
	"Jared Brinkley",
	"Jon Willliams",
	"Chris Toft",
	"Capelli di Joe Kucan di",
	"       Theodore A. Morris",
	"Carica un gioco",
	"Introduzione",
	"Inizia nuovo gioco",
	"Esci dal gioco",
	"Ringraziamenti speciali a",
	"Sake Joe Bostic-san",
	"Tim Fritz",
	"Kenny Dunne",
	"Grazie per aver giocato a \"The Hand of Fate.\"\n                                                                                "
};

static const StringListProvider k2SeqplayStringsDOSCDItalianProvider = { ARRAYSIZE(k2SeqplayStringsDOSCDItalian), k2SeqplayStringsDOSCDItalian };

static const char *const k2SeqplayTlkFilesDOSCDItalian[14] = {
	"EINTRO1",
	"EINTRO2",
	"EINTRO3",
	"EINTRO4",
	"EINTRO5",
	"EINTRO6",
	"EINTRO7",
	"EINTRO8",
	"EINTRO9",
	"EINTRO10",
	"EINTRO11",
	"EINTRO12",
	"EGLOW",
	""
};

static const StringListProvider k2SeqplayTlkFilesDOSCDItalianProvider = { ARRAYSIZE(k2SeqplayTlkFilesDOSCDItalian), k2SeqplayTlkFilesDOSCDItalian };

==> scummvm-2026.1.0.tar.xz: scummvm-2026.1.0/devtools/create_kyradat/resources/hof_dos_cd_italian.h <==
static const char *const k2SeqplayStringsDOSCDItalian[104] = {
	"Kyrandia sta svanendo!",
	"Roccia dopo roccia...",
	"...ed albero dopo albero.",
	"Kyrandia cessa di esistere!",
	"I mistici Reali sono sconcertati.",
	"Ogni libro ""\x8A"" stato consultato.",
	"Perfino Marko ed il suo nuovo aiutante sono stati invitati alla conferenza.",
	"Fortunatamente, la Mano era ferrata in materia.",
	"E finalmente un piano ""\x8A"" stato approvato.",
	"Bisogna recuperare un'Ancora di pietra",
	"dal centro della terra.",
	"Zanthia, la pi""\x97"" giovane trai Mistici, ""\x8A"" stata scelta per recuperare l'artefatto.",
	"Grazie per aver giocato a Hand of Fate.",
	"Questi mirtilli dovrebbero bastare ad aprire un portale per il centro della terra.",
	"X",
	"X",
	"Hey! Hanno rubato tutto il mio equipaggiamento!",
	"X",
	"Se pensano che vada fin laggi""\x97"" a piedi, si sbagliano di grosso!",
	"X",
	"X",
	"Sbrigati Fauno!",
	"Ragazzi, c'""\x8A"" mancato un pelo!",
	"Puoi dirlo forte. Io ho chiuso con la caccia!",
	"Ribbit.",
	"Quante volte devo dirtelo? Sei un rospo.",
	"Oh no! Abbiamo finito il formaggio!",
	"Proviamo con questo cerume. E' arancione.",
	"Mamy, mi dai l'edera?",
	"Via di qui, scio'!",
	"Tu taglio, e io scelgo.",
	"No. TU tagli e IO scelgo.",
	"Sono sempre convinto che fosse un'emerita cretinata.",
	"Non riconosceresti un pentametro in verso giambico nemmeno se ti mordesse le chiappe!",
	"Produttore Esecutivo",
	"Brett W. Sperry",
	"Direzione&Progetto",
	"Rick Gush",
	"Capo Programmatore",
	"Michael Legg",
	"Supervisione Artistica",
	"Louis Castle",
	"Joseph B. Hewitt IV",
	"Artista",
	"Rick Parks",
	"Codice aggiuntivo",
	"Philip W. Gorrow",
	"Mike Grayford",
	"Mark McCubbin",
	"Artisti",
	"Cameron Chun",
	"Cary Averett",
	"Cindy Chinn",
	"Elie Arabian",
	"Fei Cheng",
	"Ferby Miguel",
	"Frank Mendeola",
	"Jack Martin",
	"Jerry Moore",
	"X",
	"Judith Peterson",
	"Larry Miller",
	"Lenny Lee",
	"Louise Sandoval",
	"Ren Olsen",
	"Musica & Suoni",
	"Paul Mudra",
	"Frank Klepacki",
	"Dwight Okahara",
	"Pat Collins",
	"Controllo Qualit\x85",
	"Glenn Sperry",
	"Michael Lightner",
	"William Foster",
	"Jesse Clemit",
	"Jeff Fillhaber",
	"Manuale, Confezione",
	"& Realizzazione",
	"Eydie Laramore",
	"Lisa Marcinko",
	"Lauren Rifkin",
	"Congratulazioni!",
	"Grazie per aver giocato a Hand of Fate!",
	"Codice extra",
	" contatti ",
	"Scott Duckett",
	"Irvine Testers",
	"Chris McFarland",
	"Paul Moore",
	"Chad Soares",
	"Jared Brinkley",
	"Jon Willliams",
	"Chris Toft",
	"Capelli di Joe Kucan di",
	"       Theodore A. Morris",
	"Carica un gioco",
	"Introduzione",
	"Inizia nuovo gioco",
	"Esci dal gioco",
	"Ringraziamenti speciali a",
	"Sake Joe Bostic-san",
	"Tim Fritz",
	"Kenny Dunne",
	"Grazie per aver giocato a \"The Hand of Fate.\"\n                                                                                "
};

static const StringListProvider k2SeqplayStringsDOSCDItalianProvider = { ARRAYSIZE(k2SeqplayStringsDOSCDItalian), k2SeqplayStringsDOSCDItalian };

static const char *const k2SeqplayTlkFilesDOSCDItalian[14] = {
	"EINTRO1",
	"EINTRO2",
	"EINTRO3",
	"EINTRO4",
	"EINTRO5",
	"EINTRO6",
	"EINTRO7",
	"EINTRO8",
	"EINTRO9",
	"EINTRO10",
	"EINTRO11",
	"EINTRO12",
	"EGLOW",
	""
};

static const StringListProvider k2SeqplayTlkFilesDOSCDItalianProvider = { ARRAYSIZE(k2SeqplayTlkFilesDOSCDItalian), k2SeqplayTlkFilesDOSCDItalian };
